==> kubernetes-model-kustomize-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/VarFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface VarFluent<A extends VarFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildFieldref instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldSelector getFieldref();
  public FieldSelector buildFieldref();
  public A withFieldref(FieldSelector fieldref);
  public Boolean hasFieldref();
  public A withNewFieldref(String fieldPath);
  public VarFluent.FieldrefNested<A> withNewFieldref();
  public VarFluent.FieldrefNested<A> withNewFieldrefLike(FieldSelector item);
  public VarFluent.FieldrefNested<A> editFieldref();
  public VarFluent.FieldrefNested<A> editOrNewFieldref();
  public VarFluent.FieldrefNested<A> editOrNewFieldrefLike(FieldSelector item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildObjref instead.
   * @return The buildable object.
   */
  @Deprecated
  public Target getObjref();
  public Target buildObjref();
  public A withObjref(Target objref);
  public Boolean hasObjref();
  public VarFluent.ObjrefNested<A> withNewObjref();
  public VarFluent.ObjrefNested<A> withNewObjrefLike(Target item);
  public VarFluent.ObjrefNested<A> editObjref();
  public VarFluent.ObjrefNested<A> editOrNewObjref();
  public VarFluent.ObjrefNested<A> editOrNewObjrefLike(Target item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FieldrefNested<N> extends Nested<N>,FieldSelectorFluent<VarFluent.FieldrefNested<N>>{
    public N and();
    public N endFieldref();
    
  }
  public interface ObjrefNested<N> extends Nested<N>,TargetFluent<VarFluent.ObjrefNested<N>>{
    public N and();
    public N endObjref();
    
  }
  
}

==> kubernetes-model-kustomize-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/VarFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface VarFluent<A extends VarFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildFieldref instead.
   * @return The buildable object.
   */
  @Deprecated
  public FieldSelector getFieldref();
  public FieldSelector buildFieldref();
  public A withFieldref(FieldSelector fieldref);
  public Boolean hasFieldref();
  public A withNewFieldref(String fieldPath);
  public VarFluent.FieldrefNested<A> withNewFieldref();
  public VarFluent.FieldrefNested<A> withNewFieldrefLike(FieldSelector item);
  public VarFluent.FieldrefNested<A> editFieldref();
  public VarFluent.FieldrefNested<A> editOrNewFieldref();
  public VarFluent.FieldrefNested<A> editOrNewFieldrefLike(FieldSelector item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildObjref instead.
   * @return The buildable object.
   */
  @Deprecated
  public Target getObjref();
  public Target buildObjref();
  public A withObjref(Target objref);
  public Boolean hasObjref();
  public VarFluent.ObjrefNested<A> withNewObjref();
  public VarFluent.ObjrefNested<A> withNewObjrefLike(Target item);
  public VarFluent.ObjrefNested<A> editObjref();
  public VarFluent.ObjrefNested<A> editOrNewObjref();
  public VarFluent.ObjrefNested<A> editOrNewObjrefLike(Target item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FieldrefNested<N> extends Nested<N>,FieldSelectorFluent<VarFluent.FieldrefNested<N>>{
    public N and();
    public N endFieldref();
    
  }
  public interface ObjrefNested<N> extends Nested<N>,TargetFluent<VarFluent.ObjrefNested<N>>{
    public N and();
    public N endObjref();
    
  }
  
}
